# imports
library(dplyr)
library(ggplot2)
library(extrafont)

# load data
chuk <- read.table("txt/chukar-mass.txt",header=TRUE)
aos <- read.table("txt/aos-drops.txt",header=TRUE,sep="\t")
fastec <- read.table("txt/fastec-drops.txt",header=TRUE,sep="\t")
flip <- read.table("txt/flip-drops.txt",header=TRUE,sep="\t")
flip$end <- NA
flip$drop <- NA
flip$frequency <- NA
flip$yesno.success <- NA

# combine
data <- rbind(aos,fastec,flip)
data <- merge(chuk,data,by=c("bird","date"))
data <- tbl_df(data)

# For fig 1a, group and summarise by age
filtered <- filter(data,mode!="upright",mode!="wingstied",age<16)
grouped <- group_by(filtered,age)
result <- summarise(grouped,
                    prop_success = mean(success,drop.na=TRUE),
                    num_success = sum(success),
                    num_total = n())
# base plot
fig1a <- ggplot(result,aes(as.factor(age),prop_success))+
    geom_bar(stat="identity",fill="grey40")+
    xlab("age, dph")+ylab("proportion of\n successful righting")+
    ylim(0,1.0)+
    theme_bw()
# text annotations and font settings
fig1a <- fig1a+geom_text(aes(label=num_total,y=0.04),
                         family="Times New Roman",size=2,color="white")#+
#    geom_text(aes(label=num_success,y=percent_success-3),
#              colour="white",family="Times New Roman",size=2)#+
#    annotate("text",label="sample size",x=1,y=9,hjust=0.1,
#             family="Times New Roman",size=2,color="white")
# set theme
fig1a <- fig1a+theme(text=element_text(family="Times New Roman",size=9),
                     panel.grid.major=element_blank(),
                     panel.grid.minor=element_blank())
ggsave("biolett2aALT.pdf",fig1a,width=3,height=2)







# For fig 1b
filtered_b <- filter(data,
                     mode!="upright",mode!="wingstied",mode!="none",age<16,start==180)
levels(filtered_b$mode)[1] <- "unidentified"
levels(filtered_b$mode)[7] <- "pushed off"
filtered_b$mode = factor(filtered_b$mode,
    levels(filtered_b$mode)[c(1,7,3,4,5,6,2)])
# base plot
fig1b <- ggplot(filtered_b,aes(as.factor(age),fill=mode))+
    geom_bar(stat="bin",position="fill")+
    xlab("age, dph")+ylab("proportion of\n symmetric righting")+
    scale_fill_manual(values=c("unidentified"="black","pushed off"="grey60","pitch"="grey40","roll"="grey80"))+
    theme_bw()
# text annotations and font setting
fig1b <- fig1b + geom_text(data=result,inherit.aes=FALSE,
                           aes(label=num_success,y=0.96,x=age),
                           family="Times New Roman",size=2,colour="black")+
    annotate("text",label="(asymmetric righting)",x=5.5,y=0.7,
             family="Times New Roman",size=2)+
    annotate("text",label="symmetric righting",x=11.5,y=0.22,
             family="Times New Roman",size=2,colour="black")+
    annotate("text",label="pushed off",x=1.5,y=0.07,
             family="Times New Roman",size=1)+
    annotate("text",label="unidentified",x=1.5,y=0.015,
             family="Times New Roman",size=1,colour="white")

# set theme
fig1b <- fig1b+theme(text=element_text(family="Times New Roman",size=9),
                     legend.position="none",
                     panel.grid.major=element_blank(),
                     panel.grid.minor=element_blank())
ggsave("biolett2bALT.pdf",fig1b,width=3,height=2)



    

