# load the data
data <- read.table('txt/aic-sweep.txt', header=TRUE)
ages <- read.table('txt/chukar-mass.txt',header=TRUE)

# subset and merge
data$date <- factor(data$date)
ages$date <- factor(ages$date)
ages$bird <- factor(ages$bird)
data <- merge(data,ages,by=c('date','bird'))

# compute stuff
library(dplyr)
data <- mutate(data,
               age = factor(age),
               mass = mass/1000.,
               fx = mass*ax,
               fy = mass*abs(9.81+ay),
               F = (fx**2.+fy**2.)**0.5)

grouped <- group_by(data,age)
result <- summarise(grouped,
                    max = mean(ax),
                    may = mean(1+ay/9.81),
                    mfx = mean(fx),
                    mfy = mean(fy),
                    meanF = mean(F),
                    sdF = sd(F),
                    sday = sd(1+ay/9.81))

# plot stuff
library(ggplot2)
library(extrafont)
limits = aes(x=age,ymax = may+sday, ymin = may-sday)
dodge = position_dodge()

fig <- ggplot(result,aes(age,may))+
    geom_bar(stat="identity",position=dodge,fill="grey40")+
    geom_errorbar(limits,width=0,position=dodge)+
    xlab('age, dph')+
    ylab('weight-normalized\n vertical force')+
    #expression(paste('vertical acceleration, ',m/s^{2})))+
    #ylim(-0.01,0.15)+
    theme_bw()+
    theme(text=element_text(family="Times New Roman",size=9),
          panel.grid.major=element_blank(),
          panel.grid.minor=element_blank())

ggsave("biolett2c.pdf",fig,width=3,height=2)





